// Server-side workbench exports
// This file exports only the server-side createWorkbench function
// without pulling in browser-side React components

export type { WorkbenchInstance } from './types';
export { createWorkbench } from './workbench';
