import type * as React from 'react';
declare function Textarea({ className, ...props }: React.ComponentProps<'textarea'>): import("react/jsx-runtime").JSX.Element;
export { Textarea };
//# sourceMappingURL=textarea.d.ts.map