interface Logger {
    debug: (...args: unknown[]) => void;
    info: (...args: unknown[]) => void;
    warn: (...args: unknown[]) => void;
    error: (...args: unknown[]) => void;
}
export declare function useLogger(component?: string): Logger;
export {};
//# sourceMappingURL=useLogger.d.ts.map